@@ -1,9 +1,22 @@
+import logging
+import logging.handlers
 from .khan_dl import *
 import argparse
 import sys
 from art import *
 
-__version__ = "1.0.7"
+__version__ = "1.0.9"
+
+
+def set_log_level(args):
+    if not args.verbose:
+        logging.basicConfig(level=logging.ERROR)
+    elif int(args.verbose) == 1:
+        logging.basicConfig(level=logging.WARNING)
+    elif int(args.verbose) == 2:
+        logging.basicConfig(level=logging.INFO)
+    elif int(args.verbose) >= 3:
+        logging.basicConfig(level=logging.DEBUG)
 
 
 def main(argv=None):
@@ -27,23 +40,32 @@ def main(argv=None):
         action="store_true",
     )
 
+    argparser.add_argument(
+        "-v",
+        "--verbose",
+        help="Verbose Levels of log. 1 = Warning; 2 = Info; 3 = Debug",
+    )
+
     args = argparser.parse_args()
 
     if args.interactive_prompt:
+        set_log_level(args)
         tprint("KHAN-DL")
         khan_down = KhanDL()
         khan_down.download_course_interactive()
 
     elif args.course_url:
+        set_log_level(args)
         tprint("KHAN-DL")
         print("Looking up " + args.course_url + "...")
         selected_course_url = args.course_url
         khan_down = KhanDL()
-        khan_down.download_course_selected(selected_course_url)
+        khan_down.download_course_given(selected_course_url)
 
     elif args.all:
+        set_log_level(args)
         tprint("KHAN-DL")
         khan_down = KhanDL()
         all_course_urls = khan_down.get_all_courses()
         for course_url in all_course_urls:
-            khan_down.download_course_selected(course_url)
+            khan_down.download_course_given(course_url)
